@@ -264,14 +264,16 @@ def consolidate_candidate(
                             conso_anns[(ann.start, ann.end)].append(ann)
                         # The AFP entity and the model entity have different types => disambiguate or keep the model
                         elif alex == '':
-                            disambs = []
-                            for a in conso_anns[(ann.start, ann.end)]:
-                                tlex = by_lexicon(a)
-                                if ann.labelName == tlex:
-                                    disambs.append(a)
-                            if not disambs:
-                                disambs = [ann]
-                            conso_anns[(ann.start, ann.end)] = disambs
+                            # If whitelist, keep all, else try to disambiguate using model type
+                            if ann.labelName != params.white_label:
+                                disambs = []
+                                for a in conso_anns[(ann.start, ann.end)]:
+                                    tlex = by_lexicon(a)
+                                    if ann.labelName == tlex:
+                                        disambs.append(a)
+                                if not disambs:
+                                    disambs = [ann]
+                                conso_anns[(ann.start, ann.end)] = disambs
 
     sorted_annotations = sorted([item for sublist in conso_anns.values() for item in sublist],
                                 key=natural_order,
