@@ -58,6 +58,7 @@ def test_afp_entities_fr(original_doc):
     processor = AFPEntitiesProcessor()
     parameters = AFPEntitiesParameters(type=ConsolidationType.linker)
     docs = processor.process([doc], parameters)
+    write_bug_result("afp_ner_fr-document-test", docs, parameters.type)
     conso: Document = docs[0]
     assert conso.altTexts == HasLen(1)
     altText = conso.altTexts[0]
@@ -91,6 +92,11 @@ def test_afp_entities_fr(original_doc):
     assert len(conso_groups["location+wikidata"]) == 1
     assert len(conso_groups["organization+wikidata"]) == 2
 
+    doc = original_doc.copy(deep=True)
+    parameters.type = ConsolidationType.ref_first
+    docs = processor.process([doc], parameters)
+    write_bug_result("afp_ner_fr-document-test", docs, parameters.type)
+
 
 def test_afp_entities_whitelist():
     testdir = Path(__file__).parent
@@ -103,6 +109,7 @@ def test_afp_entities_whitelist():
     processor = AFPEntitiesProcessor()
     parameters = AFPEntitiesParameters()
     docs = processor.process([doc], parameters)
+    write_bug_result("afp_ner_fr-document-test-whitelist2", docs, parameters.type)
     conso: Document = docs[0]
     assert conso.altTexts == HasLen(1)
     altText = conso.altTexts[0]
@@ -138,6 +145,11 @@ def test_afp_entities_whitelist():
     assert len(conso_groups["wikidata"]) == 1
     assert len(conso_groups["location"]) == 2
 
+    doc = original_doc.copy(deep=True)
+    parameters.type = ConsolidationType.ref_first
+    docs = processor.process([doc], parameters)
+    write_bug_result("afp_ner_fr-document-test-whitelist2", docs, parameters.type)
+
 
 def test_afp_entities_suspicious():
     testdir = Path(__file__).parent
@@ -150,6 +162,7 @@ def test_afp_entities_suspicious():
     processor = AFPEntitiesProcessor()
     parameters = AFPEntitiesParameters()
     docs = processor.process([doc], parameters)
+    write_bug_result("afp_ner_es-document-test", docs, parameters.type)
     conso: Document = docs[0]
     assert len(conso.annotations) < len(original_doc.annotations)
     for a in conso.annotations:
@@ -162,6 +175,7 @@ def test_afp_entities_en(original_doc_en):
     processor = AFPEntitiesProcessor()
     parameters = AFPEntitiesParameters(type=ConsolidationType.linker)
     docs = processor.process([doc], parameters)
+    write_bug_result("afp_ner_en-document-test", docs, parameters.type)
     conso: Document = docs[0]
     assert conso.altTexts == HasLen(1)
     altText = conso.altTexts[0]
@@ -170,6 +184,11 @@ def test_afp_entities_en(original_doc_en):
         name="fingerprint", text=IsStr(regex=FINGERPRINT)
     )
 
+    doc = original_doc_en.copy(deep=True)
+    parameters.type = ConsolidationType.ref_first
+    docs = processor.process([doc], parameters)
+    write_bug_result("afp_ner_en-document-test", docs, parameters.type)
+
 
 def get_bug_documents(bug):
     datadir = Path(__file__).parent / "data"
